@@ -1,5 +1,5 @@
-/*  smtube, a small youtube browser.
-    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+/*  SMTUBE2, a small YouTube browser for SMPlayer
+    Copyright (C) 2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,38 +23,31 @@
 
 #include <QDialog>
 
+#ifdef USE_PLAYERS
+#include "players.h"
+#endif
+
 class ConfigDialog : public QDialog, public Ui::ConfigDialog
 {
-    Q_OBJECT
+	Q_OBJECT
 
 public:
-    ConfigDialog( QWidget * parent = 0, Qt::WindowFlags f = 0 );
-    ~ConfigDialog();
+	ConfigDialog( QWidget * parent = 0, Qt::WindowFlags f = 0 );
+	~ConfigDialog();
 
-public slots:
-    void setRecordingDirectory( const QString & folder );
-    void setRecordingQuality( int quality );
-    void setPlaybackQuality( int quality );
-#ifdef USE_PLAYERS
-    void setPlayerNames(QStringList names);
-    void setPlayer(QString name);
-#endif
-    void setRegion(const QString & region);
-    void setPeriod(const QString & period);
-
-public:
-    QString recordingDirectory();
-    int recordingQuality();
-    int playbackQuality();
-#ifdef USE_PLAYERS
-    QString player();
-#endif
-    QString region();
-    QString period();
+	void setPlaybackQuality(int quality);
+	int playbackQuality();
 
 #ifdef USE_PLAYERS
+	void setPlayers(QList<Player> list);
+	QList<Player> players();
+
 protected slots:
-    void playerChanged(int);
+	void on_up_button_clicked();
+	void on_down_button_clicked();
+	void on_delete_button_clicked();
+	void on_add_button_clicked();
+	void editCurrentItem();
 #endif
 };
 
