@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 #include <QRegExp>
 #include <QStringList>
 #include <QFile>
+#include <QSslSocket>
 #include "ytsig.h"
 
 #if QT_VERSION >= 0x050000
@@ -31,6 +32,8 @@
 #define USE_PLAYER_NAME
 
 QString RetrieveYoutubeUrl::user_agent;
+bool RetrieveYoutubeUrl::use_https_main = false;
+bool RetrieveYoutubeUrl::use_https_vi = false;
 
 RetrieveYoutubeUrl::RetrieveYoutubeUrl( QObject* parent ) : QObject(parent)
 {
@@ -38,16 +41,23 @@ RetrieveYoutubeUrl::RetrieveYoutubeUrl( QObject* parent ) : QObject(parent)
 	manager = new QNetworkAccessManager(this);
 
 	preferred_quality = FLV_360p;
+
+	itag_from_preferred_quality = -1;
 }
 
 RetrieveYoutubeUrl::~RetrieveYoutubeUrl() {
 }
 
 void RetrieveYoutubeUrl::fetchPage(const QString & url) {
-	//qDebug("RetrieveYoutubeUrl::fetchPage: url: %s", url.toUtf8().constData());
-
+	qDebug("RetrieveYoutubeUrl::fetchPage: url: %s", url.toUtf8().constData());
 	qDebug("RetrieveYoutubeUrl::fetchPage: user agent: '%s'", user_agent.toLatin1().constData());
 
+	if (url.toLower().startsWith("https") && !QSslSocket::supportsSsl()) {
+		qDebug("RetrieveYoutubeUrl::fetchPage: no support for ssl");
+		emit noSslSupport();
+		return;
+	}
+
 	QNetworkRequest req(url);
 	req.setRawHeader("User-Agent", user_agent.toLatin1());
 	req.setRawHeader("Accept-Language", "en-us,en;q=0.5");
@@ -65,12 +75,23 @@ void RetrieveYoutubeUrl::fetchPage(const QString & url) {
 #ifdef YT_GET_VIDEOINFO
 void RetrieveYoutubeUrl::fetchVideoInfoPage(QString url) {
 	if (url.isEmpty()) {
-		url = QString("http://www.youtube.com/get_video_info?el=detailpage&ps=default&eurl=&gl=US&hl=en&video_id=%1").arg(video_id);
+		QString scheme = use_https_vi ? "https" : "http";
+		url = QString("%2://www.youtube.com/get_video_info?video_id=%1&el=vevo&ps=default&eurl=&gl=US&hl=en").arg(video_id).arg(scheme);
+		/*
+		QString ga = QString("%2://youtube.googleapis.com/v/%1").arg(video_id).arg(scheme);
+		url = QString("%2://www.youtube.com/get_video_info?video_id=%1&eurl=%3&gl=US&hl=en").arg(video_id).arg(scheme).arg(ga);
+		*/
 	}
-	//qDebug("RetrieveYoutubeUrl::fetchVideoInfoPage: url: %s", url.toUtf8().constData());
+	qDebug("RetrieveYoutubeUrl::fetchVideoInfoPage: url: %s...", url.left(20).toUtf8().constData());
 
 	qDebug("RetrieveYoutubeUrl::fetchPage: user agent: '%s'", user_agent.toLatin1().constData());
 
+	if (url.toLower().startsWith("https") && !QSslSocket::supportsSsl()) {
+		qDebug("RetrieveYoutubeUrl::fetchVideoInfoPage: no support for ssl");
+		emit noSslSupport();
+		return;
+	}
+
 	YTSig::check(url);
 	QNetworkRequest req(url);
 	req.setRawHeader("User-Agent", user_agent.toLatin1());
@@ -87,6 +108,8 @@ void RetrieveYoutubeUrl::close() {
 }
 
 void RetrieveYoutubeUrl::gotResponse() {
+	qDebug("RetrieveYoutubeUrl::gotResponse");
+
 	QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
 
 	if (reply->error() == QNetworkReply::NoError) {
@@ -102,6 +125,7 @@ void RetrieveYoutubeUrl::gotResponse() {
 				return;
 		}
 	} else {
+		qDebug("RetrieveYoutubeUrl::gotResponse: error %d: '%s'", (int)reply->error(), reply->errorString().toUtf8().constData());
 		emit errorOcurred((int)reply->error(), reply->errorString());
 		return;
 	}
@@ -127,6 +151,7 @@ void RetrieveYoutubeUrl::gotVideoInfoResponse() {
 				return;
 		}
 	} else {
+		qDebug("RetrieveYoutubeUrl::gotVideoInfoResponse: error %d: '%s'", (int)reply->error(), reply->errorString().toUtf8().constData());
 		emit errorOcurred((int)reply->error(), reply->errorString());
 		return;
 	}
@@ -366,7 +391,10 @@ bool RetrieveYoutubeUrl::isUrlSupported(const QString & url) {
 QString RetrieveYoutubeUrl::fullUrl(const QString & url) {
 	QString r;
 	QString ID = getVideoID(url);
-	if (!ID.isEmpty()) r = "http://www.youtube.com/watch?v=" + ID;
+	if (!ID.isEmpty()) {
+		QString scheme = use_https_main ? "https" : "http";
+		r = scheme + "://www.youtube.com/watch?v=" + ID;
+	}
 	return r;
 }
 
@@ -395,6 +423,12 @@ void RetrieveYoutubeUrl::parseVideoInfo(QByteArray text) {
 	return;
 	*/
 
+	/*
+	if (fmtArray.isEmpty()) {
+		qDebug("RetrieveYoutubeUrl::parseVideoInfo: text: %s", text.constData());
+	}
+	*/
+
 	bool failed_to_decrypt_signature = false;
 
 	#if QT_VERSION >= 0x050000
@@ -490,7 +524,7 @@ void RetrieveYoutubeUrl::parseVideoInfo(QByteArray text) {
 	}
 
 	QString p_url = findPreferredUrl();
-	//qDebug("p_url: '%s'", p_url.toLatin1().constData());
+	qDebug("p_url: '%s'", p_url.toLatin1().constData());
 
 	if (!p_url.isNull()) {
 		emit gotUrls(urlMap);
@@ -505,72 +539,91 @@ void RetrieveYoutubeUrl::parseVideoInfo(QByteArray text) {
 #endif
 
 QString RetrieveYoutubeUrl::findPreferredUrl() {
-	latest_preferred_url = findPreferredUrl(urlMap, preferred_quality);
+	int itag;
+	latest_preferred_url = findPreferredUrl(urlMap, preferred_quality, &itag);
+	itag_from_preferred_quality = itag;
 	return latest_preferred_url;
 }
 
-QString RetrieveYoutubeUrl::findPreferredUrl(const QMap<int, QString>& urlMap, Quality q) {
+QString RetrieveYoutubeUrl::findPreferredUrl(const QMap<int, QString>& urlMap, Quality q, int * itag) {
 	// Choose a url according to preferred quality
 	QString p_url;
 	//Quality q = preferred_quality;
 
+	int chosen_quality = -1;
+
+	#define SETPURL(QUALITY) { \
+			p_url= urlMap.value(QUALITY, QString()); \
+			if (!p_url.isNull()) chosen_quality = QUALITY; \
+		}
+
+
 	if (q==MP4_1080p) {
-		p_url = urlMap.value(MP4_1080p, QString());
-		if (p_url.isNull()) p_url= urlMap.value(WEBM_1080p, QString());
+		SETPURL(MP4_1080p)
+		if (p_url.isNull()) SETPURL(WEBM_1080p)
 		if (p_url.isNull()) q = MP4_720p;
 	}
 
 	if (q==WEBM_1080p) {
-		p_url = urlMap.value(WEBM_1080p, QString());
-		if (p_url.isNull()) p_url= urlMap.value(MP4_1080p, QString());
+		SETPURL(WEBM_1080p)
+		if (p_url.isNull()) SETPURL(MP4_1080p)
 		if (p_url.isNull()) q = WEBM_720p;
 	}
 
 	if (q==MP4_720p) {
-		p_url = urlMap.value(MP4_720p, QString());
-		if (p_url.isNull()) p_url= urlMap.value(WEBM_720p, QString());
-		if (p_url.isNull()) p_url = urlMap.value(WEBM_480p, QString());
+		SETPURL(MP4_720p)
+		if (p_url.isNull()) SETPURL(WEBM_720p)
+		if (p_url.isNull()) SETPURL(WEBM_480p)
 		if (p_url.isNull()) q = MP4_360p;
 	}
 
 	if (q==WEBM_720p) {
-		p_url = urlMap.value(WEBM_720p, QString());
-		if (p_url.isNull()) p_url= urlMap.value(MP4_720p, QString());
+		SETPURL(WEBM_720p)
+		if (p_url.isNull()) SETPURL(MP4_720p)
 		if (p_url.isNull()) q = WEBM_480p;
 	}
 
 	if (q==WEBM_480p) {
-		p_url = urlMap.value(WEBM_480p, QString());
+		SETPURL(WEBM_480p)
 		if (p_url.isNull()) q = WEBM_360p;
 	}
 
 	if (q==MP4_360p) {
-		p_url = urlMap.value(MP4_360p, QString());
-		if (p_url.isNull()) p_url= urlMap.value(WEBM_360p, QString());
+		SETPURL(MP4_360p)
+		if (p_url.isNull()) SETPURL(WEBM_360p)
 		if (p_url.isNull()) q = FLV_360p;
 	}
 
 	if (q==WEBM_360p) {
-		p_url = urlMap.value(WEBM_360p, QString());
-		if (p_url.isNull()) p_url= urlMap.value(MP4_360p, QString());
+		SETPURL(WEBM_360p)
+		if (p_url.isNull()) SETPURL(MP4_360p)
 		if (p_url.isNull()) q = FLV_360p;
 	}
 
 	// FLV, low priority
 	if (q==FLV_480p) {
-		p_url = urlMap.value(FLV_480p, QString());
+		SETPURL(FLV_480p)
 		if (p_url.isNull()) q = FLV_360p;
 	}
 
 	if (q==FLV_360p) {
-		p_url = urlMap.value(FLV_360p, QString());
+		SETPURL(FLV_360p)
 		if (p_url.isNull()) q = FLV_240p;
 	}
 
 	if (q==FLV_240p) {
-		p_url = urlMap.value(q, QString());
+		SETPURL(q)
 	}
 
+	// If everything fails, take the first url in the map
+	if (p_url.isEmpty()) {
+		QList<int> keys = urlMap.keys();
+		if (!keys.isEmpty()) SETPURL(keys[0])
+	}
+	
+	qDebug("RetrieveYoutubeUrl::findPreferredUrl: chosen_quality: %d", chosen_quality);
+	if (itag) *itag = chosen_quality;
+
 	return p_url;
 }
 
@@ -615,4 +668,32 @@ void RetrieveYoutubeUrl::htmlDecode(QString& string) {
 	string.replace("%3D", "=", Qt::CaseInsensitive);
 }
 
+QString RetrieveYoutubeUrl::extensionForItag(int itag) {
+	QString ext = ".mp4";
+	switch (itag) {
+		case RetrieveYoutubeUrl::FLV_240p:
+		case RetrieveYoutubeUrl::FLV_360p:
+		case RetrieveYoutubeUrl::FLV_480p:
+			ext = ".flv";
+			break;
+		case RetrieveYoutubeUrl::WEBM_360p:
+		case RetrieveYoutubeUrl::WEBM_480p:
+		case RetrieveYoutubeUrl::WEBM_720p:
+		case RetrieveYoutubeUrl::WEBM_1080p:
+			ext = ".webm";
+			break;
+		case RetrieveYoutubeUrl::DASH_AUDIO_MP4_48:
+		case RetrieveYoutubeUrl::DASH_AUDIO_MP4_128:
+		case RetrieveYoutubeUrl::DASH_AUDIO_MP4_256:
+			ext = ".m4a";
+			break;
+		case RetrieveYoutubeUrl::DASH_AUDIO_WEBM_128:
+		case RetrieveYoutubeUrl::DASH_AUDIO_WEBM_192:
+			ext = ".webm";
+			break;
+	}
+
+	return ext;
+}
+
 #include "moc_retrieveyoutubeurl.cpp"
