@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2015 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 
 #define USE_SVN_VERSIONS 0
 
-#define VERSION "14.8.0"
+#define VERSION "15.5.10"
 
 #if USE_SVN_VERSIONS
 #include "svn_revision.h"
@@ -34,6 +34,13 @@
 #endif
 #endif
 
+#ifdef Q_WS_AMIGA // zzd10h
+#include "svn_revision.h"
+#include "amiga_date.h"
+#define VERSTAG_AMIGA "\0$VER: SMTube " VERSION " " DATE_AMIGA " " SVN_REVISION
+char * ver = (char *)VERSTAG_AMIGA; 
+#endif
+
 QString smtubeVersion() {
 #if USE_SVN_VERSIONS
 #ifdef Q_OS_WIN
